#20170119 version CD23.2 compatible with previous jfts syntax
import configparser
import sys

class JFTSParser:
    def __init__(self, jftsfile=None):
        self.jftsfile = jftsfile
        self.JFTFailTraceback = False
        self.Instrument = None
        self.Address = None
        self.ICT = ''
        self.TPLFile = ''
        self.LeaveTapsEnabled = False
        self.AssumeTapsEnabled = False
        self.StartState = ''
        self.EndState = ''
        self.Frequency = None
        self.MiosTaps = ""
        self.TapNr = []
        self.TapVoltage = None
        self.TapVoltage1 = None
        self.TapVoltage2 = None
        self.TapVoltage3 = None
        self.TapVoltage4 = None
        self.TapThreshold = None
        self.TapThreshold1 = None
        self.TapThreshold2 = None
        self.TapThreshold3 = None
        self.TapThreshold4 = None
        self.MilliVoltageLevels = False

    def set_jftsfile(self, jftsfile):
        self.jftsfile = jftsfile

    def read_jftsfile(self):
        if self.jftsfile != None:
            jftsparser = configparser.RawConfigParser()
            jftsparser.read(self.jftsfile)

            val = ''

            if jftsparser.has_option("Settings", "JFTFailTraceback") == True:
                val = jftsparser.get("Settings", "JFTFailTraceback")
                if val != '':
                    self.JFTFailTraceback = jftsparser.getboolean("Settings", "JFTFailTraceback")

            if jftsparser.has_option("Settings", "Instrument") == True:
                val = jftsparser.get("Settings", "Instrument")
                if val != '':
                    self.Instrument = val

            if jftsparser.has_option("Settings", "Address") == True:
                val = jftsparser.get("Settings", "Address")
                if val != '':
                    self.Address = val

            if jftsparser.has_option("Settings", "ICT") == True:
                val = jftsparser.get("Settings", "ICT")
                if val != '':
                    self.ICT = val

            if jftsparser.has_option("Settings", "TPLFile") == True:
                val = jftsparser.get("Settings", "TPLFile") 
                if val != '':
                    self.TPLFile = val

            if jftsparser.has_option("Settings", "LeaveTapsEnabled") == True:
                val = jftsparser.get("Settings", "LeaveTapsEnabled")
                if val != '':
                    self.LeaveTapsEnabled = jftsparser.getboolean("Settings", "LeaveTapsEnabled")

            if jftsparser.has_option("Settings", "AssumeTapsEnabled") == True:
                val = jftsparser.get("Settings", "AssumeTapsEnabled")
                if val != '':
                    self.AssumeTapsEnabled = jftsparser.getboolean("Settings", "AssumeTapsEnabled")

            if jftsparser.has_option("Settings", "StartState") == True:
                val = jftsparser.get("Settings", "StartState")
                if val != '':
                    self.StartState = val

            if jftsparser.has_option("Settings", "EndState") == True:
                val = jftsparser.get("Settings", "EndState")
                if val != '':
                    self.EndState = val

            if jftsparser.has_option("Settings", "Frequency") == True:
                val = jftsparser.get("Settings", "Frequency")
                if val != '':
                    self.Frequency = jftsparser.getint("Settings", "Frequency")

            if jftsparser.has_option("Settings", "MiosTaps") == True:
                val = jftsparser.get("Settings", "MiosTaps")
                if val != '':
                    if (val[0]=='"'): # or (val[0]=="'"):
                        val = val[1:-1]
                    self.MiosTaps = val

            if jftsparser.has_option("Settings", "TapNr") == True:
                val = jftsparser.get("Settings", "TapNr")
                if val != '':
                    self.TapNr = [int(x.strip()) for x in jftsparser.get("Settings", "TapNr").split(',')]

            TapVoltageIntList = []
            TapThresholdIntList = []
            if jftsparser.has_option("Settings", "TapVoltage") == True:
                val = jftsparser.get("Settings", "TapVoltage")
                if val != '':
                    TapVoltageList = jftsparser.get("Settings", "TapVoltage").split(',')
                    for x in TapVoltageList:
                        strippedTapVoltage = x.strip()
                        if strippedTapVoltage != '':
                            TapVoltageIntList.append(int(strippedTapVoltage)) 
                        else:
                            TapVoltageIntList.append(None) 

            if jftsparser.has_option("Settings", "TapThreshold") == True:
                val = jftsparser.get("Settings", "TapThreshold")
                if val != '':
                    TapThresholdList = jftsparser.get("Settings", "TapThreshold").split(',')
                    for x in TapThresholdList:
                        strippedTapThreshold = x.strip()
                        if strippedTapThreshold != '':
                            TapThresholdIntList.append(int(strippedTapThreshold))
                        else:
                            TapThresholdIntList.append(None)
                    
            if jftsparser.has_option("Settings", "TapVoltage1") == True:
                val = jftsparser.get("Settings", "TapVoltage1")
                if val != '':
                    self.TapVoltage1 = jftsparser.getint("Settings", "TapVoltage1")
                    TapVoltageIntList.append(self.TapVoltage1)
                    self.TapNr.append(1) 
                    if jftsparser.has_option("Settings", "TapThreshold1") == True:
                        val = jftsparser.get("Settings", "TapThreshold1")
                        if val != '':
                            self.TapThreshold1 = jftsparser.getint("Settings", "TapThreshold1")
                    TapThresholdIntList.append(self.TapThreshold1)

            if jftsparser.has_option("Settings", "TapVoltage2") == True:
                val = jftsparser.get("Settings", "TapVoltage2")
                if val != '':
                    self.TapVoltage2 = jftsparser.getint("Settings", "TapVoltage2")
                    TapVoltageIntList.append(self.TapVoltage2) 
                    self.TapNr.append(2) 
                    if jftsparser.has_option("Settings", "TapThreshold2") == True:
                        val = jftsparser.get("Settings", "TapThreshold2")
                        if val != '':
                            self.TapThreshold2 = jftsparser.getint("Settings", "TapThreshold2")
                    TapThresholdIntList.append(self.TapThreshold2)

            if jftsparser.has_option("Settings", "TapVoltage3") == True:
                val = jftsparser.get("Settings", "TapVoltage3")
                if val != '':
                    self.TapVoltage3 = jftsparser.getint("Settings", "TapVoltage3")
                    TapVoltageIntList.append(self.TapVoltage3) 
                    self.TapNr.append(3) 
                    if jftsparser.has_option("Settings", "TapThreshold3") == True:
                        val = jftsparser.get("Settings", "TapThreshold3")
                        if val != '':
                            self.TapThreshold3 = jftsparser.getint("Settings", "TapThreshold3")
                    TapThresholdIntList.append(self.TapThreshold3)

            if jftsparser.has_option("Settings", "TapVoltage4") == True:
                val = jftsparser.get("Settings", "TapVoltage4")
                if val != '':
                    self.TapVoltage4 = jftsparser.getint("Settings", "TapVoltage4")
                    TapVoltageIntList.append(self.TapVoltage4) 
                    self.TapNr.append(4) 
                    if jftsparser.has_option("Settings", "TapThreshold4") == True:
                        val = jftsparser.get("Settings", "TapThreshold4")
                        if val != '':
                            self.TapThreshold4 = jftsparser.getint("Settings", "TapThreshold4")
                    TapThresholdIntList.append(self.TapThreshold4)
            self.TapVoltage = TapVoltageIntList
            self.TapThreshold = TapThresholdIntList

            if jftsparser.has_option("Settings", "MilliVoltageLevels") == True:
                val = jftsparser.get("Settings", "MilliVoltageLevels")
                if val != '':
                    self.MilliVoltageLevels = jftsparser.getboolean("Settings", "MilliVoltageLevels")                    

        else:
            print("Error: jfts file is not set")
            sys.exit(2)